##  Step 5: Analyze and Mitigate Risks
To analyze data and plan initiatives for risk mitigation, use reports and diagrams.
Reports:
  * You can use the IT Component Landscape report to get a good overview of the imported IT components clustered by tech category. In the report view, apply tags to readily identify candidates for actions like phasing out, termination, or upgrade. To learn more about applying views, see [Report Views](https://help.sap.com/docs/leanix/ea/report-views?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of standard report views and learn how to use custom views.").
![Overview of IT Component through Landscape Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274edacd7a4410148b1ccce3b4ae7562_LowRes.png)
Overview of IT Component through Landscape Report
  * Use the IT Component Location report to get an overview of the geographical distribution of your servers.
  * Use the Application Sourcing report to find out where applications using certain software versions are hosted.
![Application Sourcing Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274dccf57a441014954d85ccbe8f551f_LowRes.png)
Application Sourcing Report
  * Use the Application Landscape report to understand how a particular data center location impacts your business.
![Application Landscape Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27481e4f7a441014b717da9b36ac9c33_LowRes.png)
Application Landscape Report
  * Diagrams: Make use of diagrams to visualize and explore dependencies and relations between different architectural components. To learn more about diagrams, see [Diagrams](https://help.sap.com/docs/leanix/ea/diagrams?locale=en-US&state=PRODUCTION&version=CLOUD).
![Visualize Dependencies and Relations With Diagrams](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275776c17a4410148363ff2294a2d609_LowRes.png)
Visualize Dependencies and Relations With Diagrams


With the insight gained, you will be better equipped to make informed decisions in optimizing your IT landscape and improving compliance measures effectively.
